@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* 
  * gnome-print-pango.c
  *
@@ -248,6 +249,9 @@ font_from_pango_font (PangoFont *font)
 	
 	if (FcPatternGetDouble (fcfont->font_pattern, FC_SIZE, 0, &size) != FcResultMatch)
 		return NULL;
+	if (FcPatternGetDouble (fcfont->font_pattern, FC_SIZE, 0, &size) != FcResultMatch &&
+	    FcPatternGetDouble (fcfont->font_pattern, FC_PIXEL_SIZE, 0, &size) != FcResultMatch)
+		return NULL;
 
 	return gnome_font_find_from_filename (filename, id, size);
 }
@@ -589,20 +593,18 @@ print_pango_layout_line (GnomePrintContext *gpc, PangoLayoutLine *line)
 						    &ink_rect, &logical_rect);
 		
 		if (properties.bg_color) {
-			if (!properties.fg_color)
-				gnome_print_gsave (gpc);
-				
+			gnome_print_gsave (gpc);
+
 			gnome_print_setrgbcolor (gpc,
 						 (gdouble) properties.bg_color->red / 0xFFFF,
 						 (gdouble) properties.bg_color->green / 0xFFFF,
 						 (gdouble) properties.bg_color->blue / 0xFFFF);
-			
+
 			rect_filled (gpc,
 				     logical_rect.x,    - overall_rect.y - overall_rect.height,
 				     logical_rect.width,  overall_rect.height);
-			
-			if (!properties.fg_color)
-				gnome_print_grestore (gpc);
+
+			gnome_print_grestore (gpc);
 		}
 
 		if (properties.fg_color) {
